@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 import functools
 import re
@@ -22,18 +20,17 @@ from typing import Dict, Sequence, Tuple, Type, Union
 import pkg_resources
 
 import google.api_core.client_options as ClientOptions  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
 from google.cloud.documentai_v1beta2.types import document
 from google.cloud.documentai_v1beta2.types import document_understanding
-from google.rpc import status_pb2 as status  # type: ignore
-
+from google.rpc import status_pb2  # type: ignore
 from .transports.base import DocumentUnderstandingServiceTransport, DEFAULT_CLIENT_INFO
 from .transports.grpc_asyncio import DocumentUnderstandingServiceGrpcAsyncIOTransport
 from .client import DocumentUnderstandingServiceClient
@@ -56,28 +53,24 @@ class DocumentUnderstandingServiceAsyncClient:
     parse_common_billing_account_path = staticmethod(
         DocumentUnderstandingServiceClient.parse_common_billing_account_path
     )
-
     common_folder_path = staticmethod(
         DocumentUnderstandingServiceClient.common_folder_path
     )
     parse_common_folder_path = staticmethod(
         DocumentUnderstandingServiceClient.parse_common_folder_path
     )
-
     common_organization_path = staticmethod(
         DocumentUnderstandingServiceClient.common_organization_path
     )
     parse_common_organization_path = staticmethod(
         DocumentUnderstandingServiceClient.parse_common_organization_path
     )
-
     common_project_path = staticmethod(
         DocumentUnderstandingServiceClient.common_project_path
     )
     parse_common_project_path = staticmethod(
         DocumentUnderstandingServiceClient.parse_common_project_path
     )
-
     common_location_path = staticmethod(
         DocumentUnderstandingServiceClient.common_location_path
     )
@@ -87,7 +80,8 @@ class DocumentUnderstandingServiceAsyncClient:
 
     @classmethod
     def from_service_account_info(cls, info: dict, *args, **kwargs):
-        """Creates an instance of this client using the provided credentials info.
+        """Creates an instance of this client using the provided credentials
+            info.
 
         Args:
             info (dict): The service account private key info.
@@ -102,7 +96,7 @@ class DocumentUnderstandingServiceAsyncClient:
     @classmethod
     def from_service_account_file(cls, filename: str, *args, **kwargs):
         """Creates an instance of this client using the provided credentials
-        file.
+            file.
 
         Args:
             filename (str): The path to the service account private key json
@@ -119,7 +113,7 @@ class DocumentUnderstandingServiceAsyncClient:
 
     @property
     def transport(self) -> DocumentUnderstandingServiceTransport:
-        """Return the transport used by the client instance.
+        """Returns the transport used by the client instance.
 
         Returns:
             DocumentUnderstandingServiceTransport: The transport used by the client instance.
@@ -134,12 +128,12 @@ class DocumentUnderstandingServiceAsyncClient:
     def __init__(
         self,
         *,
-        credentials: credentials.Credentials = None,
+        credentials: ga_credentials.Credentials = None,
         transport: Union[str, DocumentUnderstandingServiceTransport] = "grpc_asyncio",
         client_options: ClientOptions = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
-        """Instantiate the document understanding service client.
+        """Instantiates the document understanding service client.
 
         Args:
             credentials (Optional[google.auth.credentials.Credentials]): The
@@ -171,7 +165,6 @@ class DocumentUnderstandingServiceAsyncClient:
             google.auth.exceptions.MutualTlsChannelError: If mutual TLS transport
                 creation failed for any reason.
         """
-
         self._client = DocumentUnderstandingServiceClient(
             credentials=credentials,
             transport=transport,
@@ -203,7 +196,6 @@ class DocumentUnderstandingServiceAsyncClient:
                 This corresponds to the ``requests`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -232,7 +224,6 @@ class DocumentUnderstandingServiceAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if requests:
             request.requests.extend(requests)
 
@@ -245,7 +236,8 @@ class DocumentUnderstandingServiceAsyncClient:
                 maximum=60.0,
                 multiplier=1.3,
                 predicate=retries.if_exception_type(
-                    exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
+                    core_exceptions.DeadlineExceeded,
+                    core_exceptions.ServiceUnavailable,
                 ),
                 deadline=120.0,
             ),
@@ -286,7 +278,6 @@ class DocumentUnderstandingServiceAsyncClient:
         Args:
             request (:class:`google.cloud.documentai_v1beta2.types.ProcessDocumentRequest`):
                 The request object. Request to process one document.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -305,7 +296,6 @@ class DocumentUnderstandingServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-
         request = document_understanding.ProcessDocumentRequest(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
@@ -317,7 +307,8 @@ class DocumentUnderstandingServiceAsyncClient:
                 maximum=60.0,
                 multiplier=1.3,
                 predicate=retries.if_exception_type(
-                    exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
+                    core_exceptions.DeadlineExceeded,
+                    core_exceptions.ServiceUnavailable,
                 ),
                 deadline=120.0,
             ),
