@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,24 +13,22 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import warnings
-from typing import Awaitable, Callable, Dict, Optional, Sequence, Tuple
+from typing import Awaitable, Callable, Dict, Optional, Sequence, Tuple, Union
 
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import grpc_helpers_async  # type: ignore
 from google.api_core import operations_v1  # type: ignore
-from google import auth  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
+import packaging.version
 
 import grpc  # type: ignore
 from grpc.experimental import aio  # type: ignore
 
 from google.cloud.documentai_v1beta2.types import document
 from google.cloud.documentai_v1beta2.types import document_understanding
-from google.longrunning import operations_pb2 as operations  # type: ignore
-
+from google.longrunning import operations_pb2  # type: ignore
 from .base import DocumentUnderstandingServiceTransport, DEFAULT_CLIENT_INFO
 from .grpc import DocumentUnderstandingServiceGrpcTransport
 
@@ -60,7 +57,7 @@ class DocumentUnderstandingServiceGrpcAsyncIOTransport(
     def create_channel(
         cls,
         host: str = "us-documentai.googleapis.com",
-        credentials: credentials.Credentials = None,
+        credentials: ga_credentials.Credentials = None,
         credentials_file: Optional[str] = None,
         scopes: Optional[Sequence[str]] = None,
         quota_project_id: Optional[str] = None,
@@ -87,13 +84,15 @@ class DocumentUnderstandingServiceGrpcAsyncIOTransport(
         Returns:
             aio.Channel: A gRPC AsyncIO channel object.
         """
-        scopes = scopes or cls.AUTH_SCOPES
+
+        self_signed_jwt_kwargs = cls._get_self_signed_jwt_kwargs(host, scopes)
+
         return grpc_helpers_async.create_channel(
             host,
             credentials=credentials,
             credentials_file=credentials_file,
-            scopes=scopes,
             quota_project_id=quota_project_id,
+            **self_signed_jwt_kwargs,
             **kwargs,
         )
 
@@ -101,7 +100,7 @@ class DocumentUnderstandingServiceGrpcAsyncIOTransport(
         self,
         *,
         host: str = "us-documentai.googleapis.com",
-        credentials: credentials.Credentials = None,
+        credentials: ga_credentials.Credentials = None,
         credentials_file: Optional[str] = None,
         scopes: Optional[Sequence[str]] = None,
         channel: aio.Channel = None,
@@ -115,7 +114,8 @@ class DocumentUnderstandingServiceGrpcAsyncIOTransport(
         """Instantiate the transport.
 
         Args:
-            host (Optional[str]): The hostname to connect to.
+            host (Optional[str]):
+                 The hostname to connect to.
             credentials (Optional[google.auth.credentials.Credentials]): The
                 authorization credentials to attach to requests. These
                 credentials identify the application to the service; if none
@@ -174,7 +174,6 @@ class DocumentUnderstandingServiceGrpcAsyncIOTransport(
             # If a channel was explicitly provided, set it.
             self._grpc_channel = channel
             self._ssl_channel_credentials = None
-
         else:
             if api_mtls_endpoint:
                 host = api_mtls_endpoint
@@ -254,7 +253,7 @@ class DocumentUnderstandingServiceGrpcAsyncIOTransport(
         self,
     ) -> Callable[
         [document_understanding.BatchProcessDocumentsRequest],
-        Awaitable[operations.Operation],
+        Awaitable[operations_pb2.Operation],
     ]:
         r"""Return a callable for the batch process documents method over gRPC.
 
@@ -275,7 +274,7 @@ class DocumentUnderstandingServiceGrpcAsyncIOTransport(
             self._stubs["batch_process_documents"] = self.grpc_channel.unary_unary(
                 "/google.cloud.documentai.v1beta2.DocumentUnderstandingService/BatchProcessDocuments",
                 request_serializer=document_understanding.BatchProcessDocumentsRequest.serialize,
-                response_deserializer=operations.Operation.FromString,
+                response_deserializer=operations_pb2.Operation.FromString,
             )
         return self._stubs["batch_process_documents"]
 
