@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,13 +13,11 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import proto  # type: ignore
 
-
 from google.cloud.documentai_v1beta2.types import geometry
-from google.rpc import status_pb2 as status  # type: ignore
-from google.type import color_pb2 as gt_color  # type: ignore
+from google.rpc import status_pb2  # type: ignore
+from google.type import color_pb2  # type: ignore
 
 
 __protobuf__ = proto.module(
@@ -98,11 +95,9 @@ class Document(proto.Message):
                 in the overall document global text.
         """
 
-        shard_index = proto.Field(proto.INT64, number=1)
-
-        shard_count = proto.Field(proto.INT64, number=2)
-
-        text_offset = proto.Field(proto.INT64, number=3)
+        shard_index = proto.Field(proto.INT64, number=1,)
+        shard_count = proto.Field(proto.INT64, number=2,)
+        text_offset = proto.Field(proto.INT64, number=3,)
 
     class Label(proto.Message):
         r"""Label attaches schema information and/or other metadata to segments
@@ -129,11 +124,9 @@ class Document(proto.Message):
                 assignment.
         """
 
-        automl_model = proto.Field(proto.STRING, number=2, oneof="source")
-
-        name = proto.Field(proto.STRING, number=1)
-
-        confidence = proto.Field(proto.FLOAT, number=3)
+        automl_model = proto.Field(proto.STRING, number=2, oneof="source",)
+        name = proto.Field(proto.STRING, number=1,)
+        confidence = proto.Field(proto.FLOAT, number=3,)
 
     class Style(proto.Message):
         r"""Annotation for common text style attributes. This adheres to
@@ -162,7 +155,6 @@ class Document(proto.Message):
 
         class FontSize(proto.Message):
             r"""Font size with unit.
-
             Attributes:
                 size (float):
                     Font size for the text.
@@ -171,31 +163,25 @@ class Document(proto.Message):
                     (in, px, pt, etc.).
             """
 
-            size = proto.Field(proto.FLOAT, number=1)
-
-            unit = proto.Field(proto.STRING, number=2)
+            size = proto.Field(proto.FLOAT, number=1,)
+            unit = proto.Field(proto.STRING, number=2,)
 
         text_anchor = proto.Field(
             proto.MESSAGE, number=1, message="Document.TextAnchor",
         )
-
-        color = proto.Field(proto.MESSAGE, number=2, message=gt_color.Color,)
-
-        background_color = proto.Field(proto.MESSAGE, number=3, message=gt_color.Color,)
-
-        font_weight = proto.Field(proto.STRING, number=4)
-
-        text_style = proto.Field(proto.STRING, number=5)
-
-        text_decoration = proto.Field(proto.STRING, number=6)
-
+        color = proto.Field(proto.MESSAGE, number=2, message=color_pb2.Color,)
+        background_color = proto.Field(
+            proto.MESSAGE, number=3, message=color_pb2.Color,
+        )
+        font_weight = proto.Field(proto.STRING, number=4,)
+        text_style = proto.Field(proto.STRING, number=5,)
+        text_decoration = proto.Field(proto.STRING, number=6,)
         font_size = proto.Field(
             proto.MESSAGE, number=7, message="Document.Style.FontSize",
         )
 
     class Page(proto.Message):
         r"""A page in a [Document][google.cloud.documentai.v1beta2.Document].
-
         Attributes:
             page_number (int):
                 1-based index for current
@@ -241,7 +227,6 @@ class Document(proto.Message):
 
         class Dimension(proto.Message):
             r"""Dimension for the page.
-
             Attributes:
                 width (float):
                     Page width.
@@ -251,15 +236,12 @@ class Document(proto.Message):
                     Dimension unit.
             """
 
-            width = proto.Field(proto.FLOAT, number=1)
-
-            height = proto.Field(proto.FLOAT, number=2)
-
-            unit = proto.Field(proto.STRING, number=3)
+            width = proto.Field(proto.FLOAT, number=1,)
+            height = proto.Field(proto.FLOAT, number=2,)
+            unit = proto.Field(proto.STRING, number=3,)
 
         class Layout(proto.Message):
             r"""Visual element describing a layout unit on a page.
-
             Attributes:
                 text_anchor (google.cloud.documentai_v1beta2.types.Document.TextAnchor):
                     Text anchor indexing into the
@@ -292,18 +274,14 @@ class Document(proto.Message):
             text_anchor = proto.Field(
                 proto.MESSAGE, number=1, message="Document.TextAnchor",
             )
-
-            confidence = proto.Field(proto.FLOAT, number=2)
-
+            confidence = proto.Field(proto.FLOAT, number=2,)
             bounding_poly = proto.Field(
                 proto.MESSAGE, number=3, message=geometry.BoundingPoly,
             )
-
             orientation = proto.Field(
                 proto.ENUM, number=4, enum="Document.Page.Layout.Orientation",
             )
-
-            id = proto.Field(proto.STRING, number=5)
+            id = proto.Field(proto.STRING, number=5,)
 
         class Block(proto.Message):
             r"""A block has a set of lines (collected into paragraphs) that
@@ -322,7 +300,6 @@ class Document(proto.Message):
             layout = proto.Field(
                 proto.MESSAGE, number=1, message="Document.Page.Layout",
             )
-
             detected_languages = proto.RepeatedField(
                 proto.MESSAGE, number=2, message="Document.Page.DetectedLanguage",
             )
@@ -344,7 +321,6 @@ class Document(proto.Message):
             layout = proto.Field(
                 proto.MESSAGE, number=1, message="Document.Page.Layout",
             )
-
             detected_languages = proto.RepeatedField(
                 proto.MESSAGE, number=2, message="Document.Page.DetectedLanguage",
             )
@@ -367,14 +343,12 @@ class Document(proto.Message):
             layout = proto.Field(
                 proto.MESSAGE, number=1, message="Document.Page.Layout",
             )
-
             detected_languages = proto.RepeatedField(
                 proto.MESSAGE, number=2, message="Document.Page.DetectedLanguage",
             )
 
         class Token(proto.Message):
             r"""A detected token.
-
             Attributes:
                 layout (google.cloud.documentai_v1beta2.types.Document.Page.Layout):
                     [Layout][google.cloud.documentai.v1beta2.Document.Page.Layout]
@@ -411,11 +385,9 @@ class Document(proto.Message):
             layout = proto.Field(
                 proto.MESSAGE, number=1, message="Document.Page.Layout",
             )
-
             detected_break = proto.Field(
                 proto.MESSAGE, number=2, message="Document.Page.Token.DetectedBreak",
             )
-
             detected_languages = proto.RepeatedField(
                 proto.MESSAGE, number=3, message="Document.Page.DetectedLanguage",
             )
@@ -440,16 +412,13 @@ class Document(proto.Message):
             layout = proto.Field(
                 proto.MESSAGE, number=1, message="Document.Page.Layout",
             )
-
-            type_ = proto.Field(proto.STRING, number=2)
-
+            type_ = proto.Field(proto.STRING, number=2,)
             detected_languages = proto.RepeatedField(
                 proto.MESSAGE, number=3, message="Document.Page.DetectedLanguage",
             )
 
         class Table(proto.Message):
             r"""A table representation similar to HTML table structure.
-
             Attributes:
                 layout (google.cloud.documentai_v1beta2.types.Document.Page.Layout):
                     [Layout][google.cloud.documentai.v1beta2.Document.Page.Layout]
@@ -466,7 +435,6 @@ class Document(proto.Message):
 
             class TableRow(proto.Message):
                 r"""A row of table cells.
-
                 Attributes:
                     cells (Sequence[google.cloud.documentai_v1beta2.types.Document.Page.Table.TableCell]):
                         Cells that make up this row.
@@ -478,7 +446,6 @@ class Document(proto.Message):
 
             class TableCell(proto.Message):
                 r"""A cell representation inside the table.
-
                 Attributes:
                     layout (google.cloud.documentai_v1beta2.types.Document.Page.Layout):
                         [Layout][google.cloud.documentai.v1beta2.Document.Page.Layout]
@@ -496,11 +463,8 @@ class Document(proto.Message):
                 layout = proto.Field(
                     proto.MESSAGE, number=1, message="Document.Page.Layout",
                 )
-
-                row_span = proto.Field(proto.INT32, number=2)
-
-                col_span = proto.Field(proto.INT32, number=3)
-
+                row_span = proto.Field(proto.INT32, number=2,)
+                col_span = proto.Field(proto.INT32, number=3,)
                 detected_languages = proto.RepeatedField(
                     proto.MESSAGE, number=4, message="Document.Page.DetectedLanguage",
                 )
@@ -508,22 +472,18 @@ class Document(proto.Message):
             layout = proto.Field(
                 proto.MESSAGE, number=1, message="Document.Page.Layout",
             )
-
             header_rows = proto.RepeatedField(
                 proto.MESSAGE, number=2, message="Document.Page.Table.TableRow",
             )
-
             body_rows = proto.RepeatedField(
                 proto.MESSAGE, number=3, message="Document.Page.Table.TableRow",
             )
-
             detected_languages = proto.RepeatedField(
                 proto.MESSAGE, number=4, message="Document.Page.DetectedLanguage",
             )
 
         class FormField(proto.Message):
             r"""A form field detected on the page.
-
             Attributes:
                 field_name (google.cloud.documentai_v1beta2.types.Document.Page.Layout):
                     [Layout][google.cloud.documentai.v1beta2.Document.Page.Layout]
@@ -560,28 +520,21 @@ class Document(proto.Message):
             field_name = proto.Field(
                 proto.MESSAGE, number=1, message="Document.Page.Layout",
             )
-
             field_value = proto.Field(
                 proto.MESSAGE, number=2, message="Document.Page.Layout",
             )
-
             name_detected_languages = proto.RepeatedField(
                 proto.MESSAGE, number=3, message="Document.Page.DetectedLanguage",
             )
-
             value_detected_languages = proto.RepeatedField(
                 proto.MESSAGE, number=4, message="Document.Page.DetectedLanguage",
             )
-
-            value_type = proto.Field(proto.STRING, number=5)
-
-            corrected_key_text = proto.Field(proto.STRING, number=6)
-
-            corrected_value_text = proto.Field(proto.STRING, number=7)
+            value_type = proto.Field(proto.STRING, number=5,)
+            corrected_key_text = proto.Field(proto.STRING, number=6,)
+            corrected_value_text = proto.Field(proto.STRING, number=7,)
 
         class DetectedLanguage(proto.Message):
             r"""Detected language for a structural component.
-
             Attributes:
                 language_code (str):
                     The BCP-47 language code, such as "en-US" or "sr-Latn". For
@@ -591,46 +544,35 @@ class Document(proto.Message):
                     Confidence of detected language. Range [0, 1].
             """
 
-            language_code = proto.Field(proto.STRING, number=1)
-
-            confidence = proto.Field(proto.FLOAT, number=2)
-
-        page_number = proto.Field(proto.INT32, number=1)
+            language_code = proto.Field(proto.STRING, number=1,)
+            confidence = proto.Field(proto.FLOAT, number=2,)
 
+        page_number = proto.Field(proto.INT32, number=1,)
         dimension = proto.Field(
             proto.MESSAGE, number=2, message="Document.Page.Dimension",
         )
-
         layout = proto.Field(proto.MESSAGE, number=3, message="Document.Page.Layout",)
-
         detected_languages = proto.RepeatedField(
             proto.MESSAGE, number=4, message="Document.Page.DetectedLanguage",
         )
-
         blocks = proto.RepeatedField(
             proto.MESSAGE, number=5, message="Document.Page.Block",
         )
-
         paragraphs = proto.RepeatedField(
             proto.MESSAGE, number=6, message="Document.Page.Paragraph",
         )
-
         lines = proto.RepeatedField(
             proto.MESSAGE, number=7, message="Document.Page.Line",
         )
-
         tokens = proto.RepeatedField(
             proto.MESSAGE, number=8, message="Document.Page.Token",
         )
-
         visual_elements = proto.RepeatedField(
             proto.MESSAGE, number=9, message="Document.Page.VisualElement",
         )
-
         tables = proto.RepeatedField(
             proto.MESSAGE, number=10, message="Document.Page.Table",
         )
-
         form_fields = proto.RepeatedField(
             proto.MESSAGE, number=11, message="Document.Page.FormField",
         )
@@ -669,21 +611,14 @@ class Document(proto.Message):
         text_anchor = proto.Field(
             proto.MESSAGE, number=1, message="Document.TextAnchor",
         )
-
-        type_ = proto.Field(proto.STRING, number=2)
-
-        mention_text = proto.Field(proto.STRING, number=3)
-
-        mention_id = proto.Field(proto.STRING, number=4)
-
-        confidence = proto.Field(proto.FLOAT, number=5)
-
+        type_ = proto.Field(proto.STRING, number=2,)
+        mention_text = proto.Field(proto.STRING, number=3,)
+        mention_id = proto.Field(proto.STRING, number=4,)
+        confidence = proto.Field(proto.FLOAT, number=5,)
         page_anchor = proto.Field(
             proto.MESSAGE, number=6, message="Document.PageAnchor",
         )
-
-        id = proto.Field(proto.STRING, number=7)
-
+        id = proto.Field(proto.STRING, number=7,)
         bounding_poly_for_demo_frontend = proto.Field(
             proto.MESSAGE, number=8, message=geometry.BoundingPoly,
         )
@@ -701,11 +636,9 @@ class Document(proto.Message):
                 Relationship description.
         """
 
-        subject_id = proto.Field(proto.STRING, number=1)
-
-        object_id = proto.Field(proto.STRING, number=2)
-
-        relation = proto.Field(proto.STRING, number=3)
+        subject_id = proto.Field(proto.STRING, number=1,)
+        object_id = proto.Field(proto.STRING, number=2,)
+        relation = proto.Field(proto.STRING, number=3,)
 
     class TextAnchor(proto.Message):
         r"""Text reference indexing into the
@@ -735,9 +668,8 @@ class Document(proto.Message):
                     [Document.text][google.cloud.documentai.v1beta2.Document.text].
             """
 
-            start_index = proto.Field(proto.INT64, number=1)
-
-            end_index = proto.Field(proto.INT64, number=2)
+            start_index = proto.Field(proto.INT64, number=1,)
+            end_index = proto.Field(proto.INT64, number=2,)
 
         text_segments = proto.RepeatedField(
             proto.MESSAGE, number=1, message="Document.TextAnchor.TextSegment",
@@ -785,41 +717,29 @@ class Document(proto.Message):
                 TABLE = 6
                 FORM_FIELD = 7
 
-            page = proto.Field(proto.INT64, number=1)
-
+            page = proto.Field(proto.INT64, number=1,)
             layout_type = proto.Field(
                 proto.ENUM, number=2, enum="Document.PageAnchor.PageRef.LayoutType",
             )
-
-            layout_id = proto.Field(proto.STRING, number=3)
+            layout_id = proto.Field(proto.STRING, number=3,)
 
         page_refs = proto.RepeatedField(
             proto.MESSAGE, number=1, message="Document.PageAnchor.PageRef",
         )
 
-    uri = proto.Field(proto.STRING, number=1, oneof="source")
-
-    content = proto.Field(proto.BYTES, number=2, oneof="source")
-
-    mime_type = proto.Field(proto.STRING, number=3)
-
-    text = proto.Field(proto.STRING, number=4)
-
+    uri = proto.Field(proto.STRING, number=1, oneof="source",)
+    content = proto.Field(proto.BYTES, number=2, oneof="source",)
+    mime_type = proto.Field(proto.STRING, number=3,)
+    text = proto.Field(proto.STRING, number=4,)
     text_styles = proto.RepeatedField(proto.MESSAGE, number=5, message=Style,)
-
     pages = proto.RepeatedField(proto.MESSAGE, number=6, message=Page,)
-
     entities = proto.RepeatedField(proto.MESSAGE, number=7, message=Entity,)
-
     entity_relations = proto.RepeatedField(
         proto.MESSAGE, number=8, message=EntityRelation,
     )
-
     shard_info = proto.Field(proto.MESSAGE, number=9, message=ShardInfo,)
-
     labels = proto.RepeatedField(proto.MESSAGE, number=11, message=Label,)
-
-    error = proto.Field(proto.MESSAGE, number=10, message=status.Status,)
+    error = proto.Field(proto.MESSAGE, number=10, message=status_pb2.Status,)
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
