@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,36 +13,52 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
-from .geometry import (
-    Vertex,
-    NormalizedVertex,
-    BoundingPoly,
-)
 from .document import Document
+from .document_io import (
+    BatchDocumentsInputConfig,
+    DocumentOutputConfig,
+    GcsDocument,
+    GcsDocuments,
+    GcsPrefix,
+    RawDocument,
+)
 from .document_processor_service import (
-    ProcessRequest,
-    ProcessResponse,
+    BatchProcessMetadata,
     BatchProcessRequest,
     BatchProcessResponse,
-    BatchProcessMetadata,
+    CommonOperationMetadata,
+    HumanReviewStatus,
+    ProcessRequest,
+    ProcessResponse,
+    ReviewDocumentOperationMetadata,
     ReviewDocumentRequest,
     ReviewDocumentResponse,
-    ReviewDocumentOperationMetadata,
 )
-
+from .geometry import (
+    BoundingPoly,
+    NormalizedVertex,
+    Vertex,
+)
 
 __all__ = (
-    "Vertex",
-    "NormalizedVertex",
-    "BoundingPoly",
     "Document",
-    "ProcessRequest",
-    "ProcessResponse",
+    "BatchDocumentsInputConfig",
+    "DocumentOutputConfig",
+    "GcsDocument",
+    "GcsDocuments",
+    "GcsPrefix",
+    "RawDocument",
+    "BatchProcessMetadata",
     "BatchProcessRequest",
     "BatchProcessResponse",
-    "BatchProcessMetadata",
+    "CommonOperationMetadata",
+    "HumanReviewStatus",
+    "ProcessRequest",
+    "ProcessResponse",
+    "ReviewDocumentOperationMetadata",
     "ReviewDocumentRequest",
     "ReviewDocumentResponse",
-    "ReviewDocumentOperationMetadata",
+    "BoundingPoly",
+    "NormalizedVertex",
+    "Vertex",
 )
