@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import proto  # type: ignore
 
 
@@ -33,7 +31,6 @@ __protobuf__ = proto.module(
 
 class RawDocument(proto.Message):
     r"""Payload message of raw document content (bytes).
-
     Attributes:
         content (bytes):
             Inline document content.
@@ -42,14 +39,12 @@ class RawDocument(proto.Message):
             of the [content].
     """
 
-    content = proto.Field(proto.BYTES, number=1)
-
-    mime_type = proto.Field(proto.STRING, number=2)
+    content = proto.Field(proto.BYTES, number=1,)
+    mime_type = proto.Field(proto.STRING, number=2,)
 
 
 class GcsDocument(proto.Message):
     r"""Specifies a document stored on Cloud Storage.
-
     Attributes:
         gcs_uri (str):
             The Cloud Storage object uri.
@@ -57,14 +52,12 @@ class GcsDocument(proto.Message):
             An IANA MIME type (RFC6838) of the content.
     """
 
-    gcs_uri = proto.Field(proto.STRING, number=1)
-
-    mime_type = proto.Field(proto.STRING, number=2)
+    gcs_uri = proto.Field(proto.STRING, number=1,)
+    mime_type = proto.Field(proto.STRING, number=2,)
 
 
 class GcsDocuments(proto.Message):
     r"""Specifies a set of documents on Cloud Storage.
-
     Attributes:
         documents (Sequence[google.cloud.documentai_v1beta3.types.GcsDocument]):
             The list of documents.
@@ -82,7 +75,7 @@ class GcsPrefix(proto.Message):
             The URI prefix.
     """
 
-    gcs_uri_prefix = proto.Field(proto.STRING, number=1)
+    gcs_uri_prefix = proto.Field(proto.STRING, number=1,)
 
 
 class BatchDocumentsInputConfig(proto.Message):
@@ -101,7 +94,6 @@ class BatchDocumentsInputConfig(proto.Message):
     gcs_prefix = proto.Field(
         proto.MESSAGE, number=1, oneof="source", message="GcsPrefix",
     )
-
     gcs_documents = proto.Field(
         proto.MESSAGE, number=2, oneof="source", message="GcsDocuments",
     )
@@ -119,14 +111,13 @@ class DocumentOutputConfig(proto.Message):
 
     class GcsOutputConfig(proto.Message):
         r"""The configuration used when outputting documents.
-
         Attributes:
             gcs_uri (str):
                 The Cloud Storage uri (a directory) of the
                 output.
         """
 
-        gcs_uri = proto.Field(proto.STRING, number=1)
+        gcs_uri = proto.Field(proto.STRING, number=1,)
 
     gcs_output_config = proto.Field(
         proto.MESSAGE, number=1, oneof="destination", message=GcsOutputConfig,
