@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import proto  # type: ignore
 
 
@@ -36,9 +34,8 @@ class Vertex(proto.Message):
             Y coordinate.
     """
 
-    x = proto.Field(proto.INT32, number=1)
-
-    y = proto.Field(proto.INT32, number=2)
+    x = proto.Field(proto.INT32, number=1,)
+    y = proto.Field(proto.INT32, number=2,)
 
 
 class NormalizedVertex(proto.Message):
@@ -53,14 +50,12 @@ class NormalizedVertex(proto.Message):
             Y coordinate.
     """
 
-    x = proto.Field(proto.FLOAT, number=1)
-
-    y = proto.Field(proto.FLOAT, number=2)
+    x = proto.Field(proto.FLOAT, number=1,)
+    y = proto.Field(proto.FLOAT, number=2,)
 
 
 class BoundingPoly(proto.Message):
     r"""A bounding polygon for the detected image annotation.
-
     Attributes:
         vertices (Sequence[google.cloud.documentai_v1beta3.types.Vertex]):
             The bounding polygon vertices.
@@ -69,7 +64,6 @@ class BoundingPoly(proto.Message):
     """
 
     vertices = proto.RepeatedField(proto.MESSAGE, number=1, message="Vertex",)
-
     normalized_vertices = proto.RepeatedField(
         proto.MESSAGE, number=2, message="NormalizedVertex",
     )
