@@ -41,6 +41,8 @@ def setup_teardown():
 
 
 def test_batch_parse_form(capsys):
-    batch_parse_form_v1beta2.batch_parse_form(PROJECT_ID, INPUT_URI, BATCH_OUTPUT_URI, 120)
+    batch_parse_form_v1beta2.batch_parse_form(
+        PROJECT_ID, INPUT_URI, BATCH_OUTPUT_URI, 120
+    )
     out, _ = capsys.readouterr()
     assert "Output files" in out
